@@ -2,7 +2,8 @@ import aiohttp
 import backoff
 import requests
 import urllib.parse
-import logging
+from cdislogging import get_logger
+
 import sys
 
 import indexclient.client as client
@@ -10,6 +11,8 @@ import indexclient.client as client
 from gen3.utils import DEFAULT_BACKOFF_SETTINGS, raise_for_status
 from gen3.auth import Gen3Auth
 
+logging = get_logger("__name__")
+
 
 class Gen3Index:
     """
@@ -207,10 +210,10 @@ class Gen3Index:
         distributed identifier
 
         Args:
-             guid: string
-                 - record id
-             dist_resolution: boolean
-                - *optional* Specify if we want distributed dist_resolution or not
+            guid: string
+                - record id
+            dist_resolution: boolean
+            - *optional* Specify if we want distributed dist_resolution or not
 
         """
         rec = self.client.global_get(guid, dist_resolution)
@@ -734,7 +737,7 @@ class Gen3Index:
 
         Args:
             guid: string
-                 - record id
+                - record id
 
         Returns: Nothing
 
