@@ -34,7 +34,6 @@ import os
 import csv
 import click
 from functools import partial
-import logging
 from multiprocessing.dummy import Pool as ThreadPool
 import threading
 import copy
@@ -77,10 +76,13 @@ from gen3.utils import (
 )
 import indexclient.client as client
 from indexclient.client import Document
+from cdislogging import get_logger
 
 
 CURRENT_DIR = os.path.dirname(os.path.realpath(__file__))
 
+logging = get_logger("__name__")
+
 
 class ThreadControl(object):
     """
@@ -117,10 +119,15 @@ def get_and_verify_fileinfos_from_tsv_manifest(
         headers(list(str)): field names
 
     """
+    csv.field_size_limit(sys.maxsize)  # handle large values such as "package_contents"
     files = []
     with open(manifest_file, "r", encoding="utf-8-sig") as csvfile:
         csvReader = csv.DictReader(csvfile, delimiter=manifest_file_delimiter)
         fieldnames = csvReader.fieldnames
+        if len(fieldnames) < 2:
+            logging.warning(
+                f"The manifest delimiter ({manifest_file_delimiter}) does not seem to match the provided file"
+            )
 
         logging.debug(f"got fieldnames from {manifest_file}: {fieldnames}")
         pass_verification = True
@@ -224,6 +231,11 @@ def get_and_verify_fileinfos_from_tsv_manifest(
             if not {URLS_STANDARD_KEY, MD5_STANDARD_KEY, SIZE_STANDARD_KEY}.issubset(
                 set(output_row.keys())
             ):
+                logging.error(
+                    f"ERROR: '{row[current_column_name]}' (columns names: "
+                    f"{set(output_row.keys())}) does not have required rows: "
+                    f"{URLS_STANDARD_KEY}, {MD5_STANDARD_KEY}, {SIZE_STANDARD_KEY}"
+                )
                 is_row_valid = False
 
             if not is_row_valid:
