@@ -1,7 +1,6 @@
 """
 Module to implement is_valid_manifest_format
 """
-import logging
 import warnings
 import csv
 
@@ -15,6 +14,10 @@ from gen3.tools.indexing.manifest_columns import (
     MultiValueError,
 )
 
+from cdislogging import get_logger
+
+logging = get_logger("__name__")
+
 
 def is_valid_manifest_format(
     manifest_path,
